/**
 * @file webpack的.atom文件loader
 */
const atom = require('atom-engine-compiler');

module.exports = function (source) {
    return atom.compile({
        content: source,
        compileJSComponent: function (val, key) {
            return 'require(\'' + val + '.atom\')';
        },
        strip: true
    }).compiled.js;
};